==> gradle-9.3.0-20251117175428+0000-src.zip: gradle-9.3.0-20251117175428+0000/platforms/core-configuration/declarative-dsl-provider/src/main/kotlin/org/gradle/internal/declarativedsl/project/ProjectInterpretationSequenceStep.kt <==
/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.declarativedsl.project

import org.gradle.internal.declarativedsl.common.RunsBeforeClassScopeIsReady
import org.gradle.internal.declarativedsl.common.UnsupportedSyntaxFeatureCheck
import org.gradle.internal.declarativedsl.evaluationSchema.SimpleInterpretationSequenceStepWithConversion
import org.gradle.internal.declarativedsl.evaluator.checks.AccessOnCurrentReceiverCheck
import org.gradle.internal.declarativedsl.evaluator.defaults.ApplyModelDefaults
import org.gradle.plugin.software.internal.ProjectFeatureDeclarations


/**
 * A step in the interpretation sequence that processes the project build file and applies project type conventions
 * configured in the Settings DSL.
 */
internal
fun projectInterpretationSequenceStep(
    projectFeatureDeclarations: ProjectFeatureDeclarations,
) = SimpleInterpretationSequenceStepWithConversion(
    PROJECT_INTERPRETATION_SEQUENCE_STEP_KEY,
    features = setOf(
        ApplyModelDefaults(),
        UnsupportedSyntaxFeatureCheck.feature,
        AccessOnCurrentReceiverCheck.feature,
        RunsBeforeClassScopeIsReady()
    ),
) {
    projectEvaluationSchema(projectFeatureDeclarations)
}

internal const val PROJECT_INTERPRETATION_SEQUENCE_STEP_KEY = "project"

==> gradle-9.5.0-20260221010500+0000-src.zip: gradle-9.5.0-20260221010500+0000/platforms/core-configuration/declarative-dsl-provider/src/main/kotlin/org/gradle/internal/declarativedsl/project/ProjectInterpretationSequenceStep.kt <==
/*
 * Copyright 2024 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.declarativedsl.project

import org.gradle.internal.declarativedsl.common.RunsBeforeClassScopeIsReady
import org.gradle.internal.declarativedsl.common.UnsupportedSyntaxFeatureCheck
import org.gradle.internal.declarativedsl.evaluationSchema.SimpleInterpretationSequenceStepWithConversion
import org.gradle.internal.declarativedsl.evaluator.checks.AccessOnCurrentReceiverCheck
import org.gradle.internal.declarativedsl.evaluator.defaults.ApplyModelDefaults
import org.gradle.features.internal.binding.ProjectFeatureDeclarations


/**
 * A step in the interpretation sequence that processes the project build file and applies project type conventions
 * configured in the Settings DSL.
 */
internal
fun projectInterpretationSequenceStep(
    projectFeatureDeclarations: ProjectFeatureDeclarations,
) = SimpleInterpretationSequenceStepWithConversion(
    PROJECT_INTERPRETATION_SEQUENCE_STEP_KEY,
    features = setOf(
        ApplyModelDefaults(),
        UnsupportedSyntaxFeatureCheck.feature,
        AccessOnCurrentReceiverCheck.feature,
        RunsBeforeClassScopeIsReady()
    ),
) {
    projectEvaluationSchema(projectFeatureDeclarations)
}

internal const val PROJECT_INTERPRETATION_SEQUENCE_STEP_KEY = "project"
